salt.serializers.configparser
=============================

.. automodule:: salt.serializers.configparser
    :members:
    :noindex: salt.serializers.DeserializationError salt.serializers.SerializationError
